==> tvbox-0.2.1-py3-none-any.whl: tvbox/__init__.py <==
# -*- coding: utf-8 -*-
#
#   TV-Box
#
#                                Written in 2024 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2024 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    TV Box
    ~~~~~~

"""

from .lives import LiveStream, LiveChannel, LiveGenre
# from .lives import LiveStreamFactory
# from .lives import LiveStreamChecker
from .lives import LiveStreamScanner
from .lives import LiveParser


from .scanner import ScanContext, ScanEventHandler
from .scanner import LiveScanner

from .config import LiveConfig
from .source import SourceLoader, LiveHandler
from .loader import LiveLoader


name = 'TV-Box'

__author__ = 'Albert Moky'


__all__ = [

    'LiveStream', 'LiveChannel', 'LiveGenre',
    # 'LiveStreamFactory',
    # 'LiveStreamChecker',
    'LiveStreamScanner',
    'LiveParser',


    'ScanContext', 'ScanEventHandler',
    'LiveScanner',

    'LiveConfig',
    'SourceLoader', 'LiveHandler',
    'LiveLoader',

]

==> tvbox-0.2.3-py3-none-any.whl: tvbox/__init__.py <==
# -*- coding: utf-8 -*-
#
#   TV-Box
#
#                                Written in 2024 by Moky <albert.moky@gmail.com>
#
# ==============================================================================
# MIT License
#
# Copyright (c) 2024 Albert Moky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# ==============================================================================

"""
    TV Box
    ~~~~~~

"""

from .lives import LiveStream, LiveChannel, LiveGenre
from .lives import LiveStreamChecker, LiveStreamCreator
from .lives import LiveStreamFactory
from .lives import LiveStreamScanner
from .lives import LiveParser


from .scanner import ScanContext, ScanEventHandler
from .scanner import LiveScanner

from .config import LiveConfig
from .source import SourceLoader, LiveHandler
from .loader import LiveLoader


name = 'TV-Box'

__author__ = 'Albert Moky'


__all__ = [

    'LiveStream', 'LiveChannel', 'LiveGenre',
    'LiveStreamChecker', 'LiveStreamCreator',
    'LiveStreamFactory',
    'LiveStreamScanner',
    'LiveParser',


    'ScanContext', 'ScanEventHandler',
    'LiveScanner',

    'LiveConfig',
    'SourceLoader', 'LiveHandler',
    'LiveLoader',

]
